@@ -5,34 +5,42 @@ from configparser import ConfigParser
 from itertools import islice
 from pathlib import Path
 
-import chardet
+import magic
+import pdfplumber
 
-from plagdef.model.legacy.algorithm import Document
+from plagdef.model.models import Document
 
 
 class DocumentFileRepository:
-    def __init__(self, dir_path: Path, lang: str, recursive=False):
+    def __init__(self, dir_path: Path, lang: str, recursive=False, at_least_two=True):
         self.lang = lang
-        self._documents = []
+        self._dir_path = dir_path
+        self._recursive = recursive
         if not dir_path.is_dir():
             raise NotADirectoryError(f'The given path {dir_path} does not point to an existing directory!')
-        if not any(dir_path.iterdir()) or not next(islice(dir_path.iterdir(), 1, None), None):
+        if at_least_two and (not any(dir_path.iterdir()) or not next(islice(dir_path.iterdir(), 1, None), None)):
             raise NoDocumentFilePairFoundError(f'The directory {dir_path} must contain at least two documents.')
-        if recursive:
-            doc_files = [file_path for file_path in dir_path.rglob('*') if file_path.is_file()]
-        else:
-            doc_files = [file_path for file_path in dir_path.iterdir() if file_path.is_file()]
-        try:
-            for file in doc_files:
-                raw_data = file.read_bytes()
-                enc = chardet.detect(raw_data)['encoding']
-                self._documents.append(Document(file.stem, file.read_text(encoding=enc)))
-        except UnicodeDecodeError as e:
-            raise UnsupportedFileFormatError(f'The directory {dir_path} contains files in an unsupported format.') \
-                from e
 
     def list(self) -> [Document]:
-        return self._documents
+        if self._recursive:
+            doc_files = [file_path for file_path in self._dir_path.rglob('*') if file_path.is_file()]
+        else:
+            doc_files = [file_path for file_path in self._dir_path.iterdir() if file_path.is_file()]
+        documents = []
+        for file in doc_files:
+            if file.suffix == '.pdf':
+                with pdfplumber.open(file) as pdf:
+                    text = ' '.join(page.extract_text() for page in pdf.pages)
+            else:
+                try:
+                    detect_enc = magic.Magic(mime_encoding=True)
+                    enc = detect_enc.from_buffer(open(str(file), 'rb').read())
+                    text = file.read_text(encoding=enc)
+                except (UnicodeDecodeError, LookupError):
+                    raise UnsupportedFileFormatError(f'The file {file.name} has an unsupported encoding'
+                                                     f' and cannot be read.')
+            documents.append(Document(file.stem, str(text)))
+        return documents
 
 
 class DocumentPairReportFileRepository:
